Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4861)

Unified Diff: chrome/common/pref_names.cc

Issue 2694893002: Integrate SMS service with Desktop iOS promotion (Closed)
Patch Set: nits Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/pref_names.h ('k') | chrome/test/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/pref_names.cc
diff --git a/chrome/common/pref_names.cc b/chrome/common/pref_names.cc
index 65421df7b16e998e611f820caf0ee088d49bb601..a6f312579bf1e2d3b42d98bc1446d0f4db972ade 100644
--- a/chrome/common/pref_names.cc
+++ b/chrome/common/pref_names.cc
@@ -2408,14 +2408,36 @@ const char kGoogleDSEGeolocationSetting[] = "google_dse_geolocation_setting";
const char kWebShareVisitedTargets[] = "profile.web_share.visited_targets";
#if defined(OS_WIN)
-// True if the user is eligible to recieve "desktop to iOS" promotion.
+// True if the user is eligible to recieve "desktop to iOS" promotion. This
+// vlaue is set by a job that access the growth table to check users with iOS
+// devices and phone recovery number and update the eligibility on chrome sync.
const char kIOSPromotionEligible[] = "ios.desktoptomobileeligible";
// True if the "desktop to iOS" promotion was successful, i.e. user installed
// the application and signed in after seeing the promotion and receiving the
// SMS.
const char kIOSPromotionDone[] = "ios.desktop_ios_promo_done";
+// Index of the entry point that last initiated sending the SMS to the user for
+// the "desktop to iOS" promotion (see DesktopIOSPromotion.IOSSigninReason
+// histogram for details).
+const char kIOSPromotionSMSEntryPoint[] =
+ "ios.desktop_ios_promo_sms_entrypoint";
+
+// Bit mask that represents the Indices of all the entry points shown to the
+// user for "desktop to iOS" promotion. Each entry point is represented by
+// 1<<entrypoint_value using the values from the Enum
+// desktop_ios_promotion::PromotionEntryPoint.
+const char kIOSPromotionShownEntryPoints[] =
+ "ios.desktop_ios_promo_shown_entrypoints";
+
+// Timestamp of the last "desktop to iOS" promotion last impression. If the
+// user sends SMS on that impression then we deal with this timestamp as the
+// SMS sending time because after sending the sms the user shouldn't see the
+// promotion again (Accuracy to the minutes and seconds is not important).
+const char kIOSPromotionLastImpression[] =
+ "ios.desktop_ios_promo_last_impression";
+
// Number of times user has seen the "desktop to iOS" save passwords bubble
// promotion.
const char kNumberSavePasswordsBubbleIOSPromoShown[] =
@@ -2408,14 +2408,36 @@ const char kGoogleDSEGeolocationSetting[] = "google_dse_geolocation_setting";
const char kIOSPromotionEligible[] = "ios.desktoptomobileeligible";
// True if the "desktop to iOS" promotion was successful, i.e. user installed
-// the application and signed in after seeing the promotion and receiving the
-// SMS.
+// the application and signed in on the iOS client after seeing the promotion
+// and receiving the SMS.
const char kIOSPromotionDone[] = "ios.desktop_ios_promo_done";
« no previous file with comments | « chrome/common/pref_names.h ('k') | chrome/test/BUILD.gn » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698